@@ -16,8 +16,8 @@ typedef boost::dynamic_bitset<> blade;
 typedef std::map<blade, long double> clifford;
 typedef std::tuple<blade, int> blade_and_sign;
 
-clifford remove_zeros(clifford &C){
-    for(auto it=C.cbegin() ; it != C.end() ;){
+inline clifford remove_zeros(clifford C){
+    for(auto it = C.cbegin() ; it != C.end() ;){
         if(it->second == 0){
             it = C.erase(it); //increments pointer
         } else {
@@ -29,7 +29,7 @@ clifford remove_zeros(clifford &C){
 
 clifford prepare(const List &L, const NumericVector &d, const NumericVector &m){
     clifford out;
-    const size_t n=L.size();
+    const size_t n = L.size();
     if(!((unsigned int) n == d.length())){
         throw std::range_error("in prepare(L,d,m) [file inst/clifford.h], L must be the same length as d");
     }
@@ -44,7 +44,7 @@ clifford prepare(const List &L, const NumericVector &d, const NumericVector &m){
             out[b] += d[i];  // the meat
         } // if d[i] closes
     }  // i loop closes
-    return remove_zeros(out);
+    return remove_zeros(std::move(out));
 }
 
 Rcpp::IntegerVector which(const blade b){ // takes a blade, returns which(blade)
@@ -60,7 +60,7 @@ Rcpp::IntegerVector which(const blade b){ // takes a blade, returns which(blade)
 List Rblades(const clifford &C){  // takes a clifford object, returns a list of which(blades); used in retval()
     List out;
 
-    for(auto ic=C.cbegin(); ic != C.end(); ++ic){
+    for(auto ic = C.cbegin() ; ic != C.end() ; ++ic){
         out.push_back(which(ic->first));
     }
     return out;
@@ -68,9 +68,9 @@ List Rblades(const clifford &C){  // takes a clifford object, returns a list of
 
 NumericVector coeffs(const clifford &C){  // takes a clifford object, returns the coefficients
     NumericVector out(C.size());
-    unsigned int i=0;
+    unsigned int i = 0;
 
-    for(auto ic=C.cbegin(); ic != C.end(); ++ic){
+    for(auto ic = C.cbegin() ; ic != C.end() ; ++ic){
         out[i] = ic->second;
         i++;
     }
@@ -78,22 +78,22 @@ NumericVector coeffs(const clifford &C){  // takes a clifford object, returns th
 }
 
 List retval(const clifford &C){  // used to return a list to R
-        return List::create(Named("blades") =  Rblades(C),
-                            Named("coeffs") =  coeffs(C)
+        return List::create(Named("blades") = Rblades(C),
+                            Named("coeffs") = coeffs(C)
                             );
 }
 
-clifford c_add(clifford cliff1, clifford cliff2){
+clifford add_lowlevel(clifford cliff1, clifford cliff2){
     if(cliff1.size() > cliff2.size()){ // #1 is bigger, so iterate through #2
         for(const auto& [blade2, value2] : cliff2 ){
             cliff1[blade2] += value2;
         }
-        return remove_zeros(cliff1);
+        return remove_zeros(std::move(cliff1));
     } else {  // L2 is bigger
         for(const auto& [blade1, value1] : cliff1 ){
             cliff2[blade1] += value1;
         }
-        return remove_zeros(cliff2);
+        return remove_zeros(std::move(cliff2));
     }
 }
 
@@ -144,16 +144,16 @@ clifford c_general_prod(const clifford &C1, const clifford &C2, const NumericVec
     int sign;
     for(const auto &[b1, value1] : C1 ){
         for(const auto &[b2, value2] : C2 ){
-            if(chooser(b1,b2)){
+            if(chooser(b1, b2)){
                 std::tie(b, sign) = juxtapose(b1, b2, signature);
                 out[b] += sign * value1 * value2; // the meat
             }
         }
     }
-    return remove_zeros(out);
+    return remove_zeros(std::move(out));
 }
 
-bool c_equal(clifford C1, clifford C2){
+bool equal_lowlevel(clifford C1, clifford C2){
     // modelled on spray_equality()
     if(C1.size() != C2.size()){
         return false;
@@ -168,7 +168,7 @@ bool c_equal(clifford C1, clifford C2){
     return true;
 }
 
-clifford c_grade(const clifford &C, const NumericVector &n){
+clifford grade_lowlevel(const clifford &C, const NumericVector &n){
     clifford out;
     for(size_t i=0 ; i < (size_t) n.length() ; ++i){
         for(const auto& [b, value] : C){
@@ -202,10 +202,10 @@ blade int_vec_to_blade(const IntegerVector iv, const int m){
   return b;
 }
 
-NumericVector c_coeffs_of_blades(clifford C,
-                                 const List &B,
-                                 const NumericVector &m
-                                 ){
+NumericVector coeffs_lowlevel(clifford C,
+                              const List &B,
+                              const NumericVector &m
+                              ){
     Rcpp::NumericVector out;
     for(size_t i=0 ; i < (size_t) B.size() ; ++i){
         const IntegerVector iv = B[i];
@@ -229,7 +229,7 @@ bool fatdotchooser          (const blade b1, const blade b2){return ((( b1 & ~b2
 bool lefttickchooser        (const blade b1, const blade b2){return ( ( b1 & ~b2).count() == 0)                                                                   ;}
 bool righttickchooser       (const blade b1, const blade b2){return ( (~b1 &  b2).count() == 0)                                                                   ;}
 
-clifford c_geometricprod(const clifford &C1, const clifford &C2, const NumericVector &signature){ return c_general_prod(C1, C2, signature, &geometricproductchooser);}
+clifford geometricprod_lowlevel(const clifford &C1, const clifford &C2, const NumericVector &signature){ return c_general_prod(C1, C2, signature, &geometricproductchooser);}
 clifford outerprod      (const clifford &C1, const clifford &C2, const NumericVector &signature){ return c_general_prod(C1, C2, signature, &outerproductchooser    );}
 clifford innerprod      (const clifford &C1, const clifford &C2, const NumericVector &signature){ return c_general_prod(C1, C2, signature, &innerproductchooser    );}
 clifford fatdotprod     (const clifford &C1, const clifford &C2, const NumericVector &signature){ return c_general_prod(C1, C2, signature, &fatdotchooser          );}
@@ -243,7 +243,7 @@ clifford overwrite(clifford C1, const clifford C2){  // C1[] <- C2
     return C1;
 }
 
-clifford c_power(const clifford &C, const NumericVector &power, const NumericVector &signature){  // p for power
+clifford power_lowlevel(const clifford &C, const NumericVector &power, const NumericVector &signature){  // p for power
     clifford out;
     unsigned int p = power[0];
 
@@ -253,7 +253,7 @@ clifford c_power(const clifford &C, const NumericVector &power, const NumericVec
     } else {
         out = C;
         for( ; p>1; p--){
-            out = c_geometricprod(C,out, signature);
+            out = geometricprod_lowlevel(C,out, signature);
         }
     }
     return out;
@@ -262,7 +262,7 @@ clifford c_power(const clifford &C, const NumericVector &power, const NumericVec
 clifford cartan(const clifford &C, const NumericVector &n){ // Appendix B of Hitzer and Sangwine: Cl(p,q) -> cl(p-4,q+4)
     clifford out;
 
-    for (auto ic=C.begin(); ic != C.end(); ++ic){
+    for (auto ic=C.begin() ; ic != C.end() ; ++ic){
         blade c = ic->first;
         const size_t o = n[0]-1; // "-1" so the numbers match; off-by-one
         if(c.size() < o+5){c.resize(o+5);}
